require 'yaml'

module Moj
  module Tribunals
    class ConfigLoader 
      attr_accessor :config_path

      def initialize(config_path=default_config_path)
        self.config_path = config_path
      end

      def load
        data = {}
        config_files.each do |file|
          name = File.basename(file).split('.').first.to_sym

          loaded_config = load_file(file)
          data[name] = loaded_config['tribunal']
        end
        data
      end

      def config_file_for(tribunal_name)
        config_files.find{|f| File.basename(f) == tribunal_name.to_s + '.yml'}
      end

      def config_files
        Dir.glob(File.join(config_path, '*.yml'))
      end

      def load_file(file)
        YAML.load_file(file)
      end

      private

        def default_config_path
          File.expand_path(
            File.join( 
              File.dirname(__FILE__), 
              '..', '..', '..', 'config', 'tribunals' 
            )
          )
        end
    end
  end
end